@@ -37,8 +37,9 @@ def process(
     vcf_file: str,
     report_file: str,
     local_output_dir: str,
+    source_file_id: str,
     phc_output_dir: str = ".lifeomic/foundation",
-) -> None:
+) -> dict[str, str]:
     with scoped_logger(__name__) as log:
         xml_dict = read_xml(xml_file)
         customer_info_dict = xml_dict["rr:ResultsReport"]["rr:CustomerInformation"]
@@ -49,7 +50,11 @@ def process(
         base_xml_name = Path(xml_file).stem
 
         vcf_name = f"{local_output_dir}/{base_xml_name}/{base_xml_name}.tcf"
-        write_vcf_to_manifest = vcf_etl(vcf_file, vcf_name, base_xml_name)
+        vcf_line_count = vcf_etl(vcf_file, vcf_name, base_xml_name, xml_file, log)
+        write_cnv = extract_copy_numbers(results_payload_dict, base_xml_name, local_output_dir, log)
+        write_fnv = extract_fusion_variant(
+            results_payload_dict, base_xml_name, local_output_dir, log
+        )
 
         yaml_file = get_test_yml(
             customer_info_dict,
@@ -57,17 +62,31 @@ def process(
             base_xml_name,
             local_output_dir,
             report_file,
-            write_vcf_to_manifest,
+            {"cnv": write_cnv, "vcf": vcf_line_count != 0, "fnv": write_fnv},
             phc_output_dir,
+            source_file_id,
         )
 
-        extract_copy_numbers(results_payload_dict, base_xml_name, local_output_dir, log)
-
-        extract_fusion_variant(results_payload_dict, base_xml_name, local_output_dir, log)
-
         with open(
             f"{local_output_dir}/{base_xml_name}/{base_xml_name}.ga4gh.genomics.yml",
             "w",
         ) as file:
             yaml = YAML()
             yaml.dump(yaml_file, file)
+
+        # Hard-code genome reference for FMI
+        genome_reference = "GRCh37"
+
+        case_metadata = {
+            "test_type": yaml_file["testType"],
+            "vcf_line_count": vcf_line_count,
+            "case_id": base_xml_name,
+            "somatic_genome_reference": genome_reference,
+        }
+
+        if write_cnv:
+            case_metadata["cnv_genome_reference"] = genome_reference
+        if write_fnv:
+            case_metadata["structural_genome_reference"] = genome_reference
+
+        return case_metadata
