@@ -1,6 +1,12 @@
 import os
 from shutil import copyfile
-from typing import Union
+from typing import Union, TypedDict, Optional
+
+
+class WriteToManifest(TypedDict):
+    vcf: bool
+    fnv: bool
+    cnv: bool
 
 
 def is_number(s: str):
@@ -66,10 +72,11 @@ def get_non_human_content(nhc_dicts) -> list:
     return nhc_final
 
 
-def get_plasma_tumor_fraction(genes) -> str:
+def get_plasma_tumor_fraction(genes) -> Optional[str]:
     ptf_dict = {
         "Elevated Tumor Fraction": "Elevated",
         "Elevated Tumor Fraction Not Detected": "Not Elevated",
+        "Cannot Be Determined": "Undetermined",
     }
     ptf_entry = [
         entry for entry in genes.get("Gene", {}) if entry.get("Name", "") == "Tumor Fraction"
@@ -87,10 +94,11 @@ def get_test_yml(
     base_xml_name: str,
     local_output_dir: str,
     report_file: str,
-    write_vcf_to_manifest: bool,
+    write_to_manifest: WriteToManifest,
     phc_output_dir: str,
+    source_file_id: str,
 ) -> dict:
-    npi = customer_info_dict.get("rr:NPI", {})
+    npi = customer_info_dict.get("rr:NPI", "")
     pmi = results_payload_dict.get("FinalReport", {}).get("PMI", {})
     signatures = results_payload_dict.get("FinalReport", {}).get("Signatures")
     sample = results_payload_dict.get("FinalReport", {}).get("Sample", {})
@@ -109,6 +117,9 @@ def get_test_yml(
 
     os.makedirs(f"{local_output_dir}/{base_xml_name}", exist_ok=True)
 
+    # Hard-code genome reference for FMI
+    genome_reference = "GRCh37"
+
     mrn = get_mrn(pmi)
 
     trf = get_trf(sample)
@@ -130,7 +141,7 @@ def get_test_yml(
     yaml_file = {
         "name": "Foundation Medicine",
         "reference": "GRCh37",
-        "sourceFile": f"{base_xml_name}.xml",
+        "sourceFileId": source_file_id,
         "testType": sample.get("TestType"),
         "indexedDate": indexedDate,
         "receivedDate": receivedDate,
@@ -145,31 +156,41 @@ def get_test_yml(
         "orderingMDName": ordering_md_info[0],
         "orderingMDNPI": ordering_md_info[1],
         "bodySite": variant_report.get("@tissue-of-origin"),
-        "bodySiteSystem": "http://foundation.com/bodySite",
+        "bodySiteSystem": "http://lifeomic.com/fhir/sequence-body-site",
         "bodySiteDisplay": variant_report.get("@tissue-of-origin"),
-        "diagnosis": pmi.get("SubmittedDiagnosis"),
-        "diagnosisDisplay": pmi.get("SubmittedDiagnosis"),
-        "diagnosisSystem": "http://foundation.com/diagnosis",
-        "files": [
+        "indication": pmi.get("SubmittedDiagnosis"),
+        "indicationDisplay": pmi.get("SubmittedDiagnosis"),
+        "indicationSystem": "http://lifeomic.com/fhir/sequence-indication",
+        "files": [],
+    }
+
+    if write_to_manifest["cnv"]:
+        yaml_file["files"].append(
             {
                 "type": "copyNumberVariant",
                 "sequenceType": "somatic",
                 "fileName": f"{phc_output_dir}/{base_xml_name}/{base_xml_name}.copynumber.csv",
-            },
+                "reference": genome_reference,
+            }
+        )
+
+    if write_to_manifest["fnv"]:
+        yaml_file["files"].append(
             {
                 "type": "structuralVariant",
                 "sequenceType": "somatic",
                 "fileName": f"{phc_output_dir}/{base_xml_name}/{base_xml_name}.structural.csv",
-            },
-        ],
-    }
+                "reference": genome_reference,
+            }
+        )
 
-    if write_vcf_to_manifest:
+    if write_to_manifest["vcf"]:
         yaml_file["files"].append(
             {
                 "type": "shortVariant",
                 "sequenceType": "somatic",
                 "fileName": f"{phc_output_dir}/{base_xml_name}/{base_xml_name}.nrm.vcf.gz",
+                "reference": genome_reference,
             }
         )
 
